@@ -1,7 +1,7 @@
 package Regexp::Pattern::Example;
 
 our $DATE = '2018-09-10'; # DATE
-our $VERSION = '0.2.5'; # VERSION
+our $VERSION = '0.2.6'; # VERSION
 
 # BEGIN_BLOCK: def
 
@@ -128,7 +128,7 @@ Regexp::Pattern::Example - An example Regexp::Pattern::* module
 
 =head1 VERSION
 
-This document describes version 0.2.5 of Regexp::Pattern::Example (from Perl distribution Regexp-Pattern), released on 2018-09-10.
+This document describes version 0.2.6 of Regexp::Pattern::Example (from Perl distribution Regexp-Pattern), released on 2018-09-10.
 
 =head1 SYNOPSIS
 
@@ -189,10 +189,10 @@ Choose variant.
 Examples:
 
  # An example that matches
- "123-456" =~ re("Example::re3");  # matches
+ "123-456" =~ re("Example::re3", {variant=>"A"});  # matches
 
  # An example that doesn't match
- "123-456" =~ re("Example::re3");  # doesn't match
+ "123-456" =~ re("Example::re3", {variant=>"B"});  # doesn't match
 
 =item * re4
 
